#ifndef VIMPAL_H
#define VIMPAL_H

#include <QWidget>

#include "profile.h"

class QFileSystemModel;
class QModelIndex;
class QTreeView;
class QComboBox;

class VimPal: public QWidget
{
    Q_OBJECT

public:
    VimPal(QWidget* parent = 0, Qt::WindowFlags f = 0);

protected:
    void closeEvent(QCloseEvent* e);

private slots:
    void goHome();
    void goUp();

    void fileClick(const QModelIndex& idx);
    void fileDblClick(const QModelIndex& idx);
    void contextMenu(const QPoint& pos);

    void editPreferences();
    void editProfiles();

    void profileChanged(int prof);

    void showAbout();

private:
    bool vimCmd(const QString& cmd, bool startNew);
    bool vimServerExists(const QString& name);
    void selectFile(const QModelIndex& idx);
    void selectDir(const QModelIndex& idx);
    void deleteFile(const QModelIndex& idx);
    void renameFile(const QModelIndex& idx);
    void newFile(const QModelIndex& idx);
    void newDirectory(const QModelIndex& idx);
    void updateProfiles();
    void updateColors();

    QString getDir(const QModelIndex& idx);

private:
    QFileSystemModel* mDirModel;
    QTreeView* mDirView;
    QComboBox* mProfileBox;

    bool mSingleClickOpen,
         mChangeDir,
         mOpenNewTabs,
         mDarkBackground,
         mShowHidden;

    QString mVimCommand;

    int mCurrentProfile,
        mLastPressedButton;

    QList<Profile> mProfiles;
};

#endif   // VIMPAL_H
